@@ -248,7 +248,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                 if (!empty($_POST['container']) && !empty($_POST['operation'])) {
                     $container = trim($_POST['container']);
                     $operation = trim($_POST['operation']);
-                    $allowed_containers = ['mysql', 'haproxy-manager', 'memcache'];
+                    $allowed_containers = ['mysql', 'haproxy-manager', 'memcache', 'postgresql'];
                     $allowed_operations = ['start', 'stop', 'restart', 'pull_recreate'];
                     
                     if (!in_array($container, $allowed_containers) || !in_array($operation, $allowed_operations)) {
@@ -722,7 +722,7 @@ $server_ip = $dns_validator->getServerIPAddress();
 
 // Get Docker container status
 $container_status = [];
-$containers = ['mysql', 'haproxy-manager', 'memcache'];
+$containers = ['mysql', 'haproxy-manager', 'memcache', 'postgresql'];
 foreach ($containers as $container) {
     $status = trim(shell_exec("docker ps --filter name=$container --format '{{.Status}}' 2>/dev/null"));
     if (!empty($status)) {
@@ -869,33 +869,33 @@ $default_ttl = $current_config['default_ttl'] ?? 3600;
                 <form id="serviceRestartForm">
                     <input type="hidden" name="action" value="restart_services">
                     <div class="mb-3">
-                        <label class="form-label">Restart Services</label>
-                        <div class="row">
-                            <div class="col-md-2">
+                        <label class="form-label text-center d-block">Restart Services</label>
+                        <div class="row justify-content-center">
+                            <div class="col-auto">
                                 <div class="form-check">
                                     <input class="form-check-input" type="checkbox" name="services[]" value="httpd" id="service-httpd">
                                     <label class="form-check-label" for="service-httpd">Apache (httpd)</label>
                                 </div>
                             </div>
-                            <div class="col-md-2">
+                            <div class="col-auto">
                                 <div class="form-check">
                                     <input class="form-check-input" type="checkbox" name="services[]" value="php-fpm" id="service-php">
                                     <label class="form-check-label" for="service-php">PHP-FPM</label>
                                 </div>
                             </div>
-                            <div class="col-md-2">
+                            <div class="col-auto">
                                 <div class="form-check">
                                     <input class="form-check-input" type="checkbox" name="services[]" value="docker" id="service-docker">
                                     <label class="form-check-label" for="service-docker">Docker</label>
                                 </div>
                             </div>
-                            <div class="col-md-2">
+                            <div class="col-auto">
                                 <div class="form-check">
                                     <input class="form-check-input" type="checkbox" name="services[]" value="network" id="service-network">
                                     <label class="form-check-label" for="service-network">Network</label>
                                 </div>
                             </div>
-                            <div class="col-md-2">
+                            <div class="col-auto">
                                 <div class="form-check">
                                     <input class="form-check-input" type="checkbox" name="services[]" value="proftpd" id="service-proftpd">
                                     <label class="form-check-label" for="service-proftpd">FTP (ProFTPD)</label>
@@ -903,9 +903,11 @@ $default_ttl = $current_config['default_ttl'] ?? 3600;
                             </div>
                         </div>
                     </div>
-                    <button type="submit" class="btn btn-warning" id="restartServicesBtn">
-                        <i class="fa fa-refresh"></i> Restart Selected Services
-                    </button>
+                    <div class="text-center">
+                        <button type="submit" class="btn btn-warning" id="restartServicesBtn">
+                            <i class="fa fa-refresh"></i> Restart Selected Services
+                        </button>
+                    </div>
                 </form>
             </div>
         </div>
@@ -955,6 +957,7 @@ $default_ttl = $current_config['default_ttl'] ?? 3600;
                                 <select class="form-control" id="container" name="container" required>
                                     <option value="">Select Container</option>
                                     <option value="mysql">MariaDB (mysql)</option>
+                                    <option value="postgresql">PostgreSQL</option>
                                     <option value="haproxy-manager">HAProxy Manager</option>
                                     <option value="memcache">Memcache</option>
                                 </select>
